.. _interfaces_module:

:mod:`pyramid.interfaces`
----------------------------

.. automodule:: pyramid.interfaces

Event-Related Interfaces
++++++++++++++++++++++++

  .. autointerface:: IApplicationCreated

  .. autointerface:: INewRequest

  .. autointerface:: IContextFound

  .. autointerface:: INewResponse

  .. autointerface:: IBeforeRender

Other Interfaces
++++++++++++++++

  .. autointerface:: IExceptionResponse

  .. autointerface:: IRoute

  .. autointerface:: IRoutePregenerator

  .. autointerface:: ISession

  .. autointerface:: ISessionFactory

  .. autointerface:: IRendererInfo

  .. autointerface:: ITemplateRenderer

  .. autointerface:: IViewMapperFactory

  .. autointerface:: IViewMapper

